@@ -3,7 +3,10 @@ use anyhow::{Context, Result};
 use std::collections::HashMap;
 use std::error::Error;
 use std::str;
-use tui::style::{Color, Modifier, Style};
+use tui::{
+    style::{Color, Modifier, Style},
+    symbols::bar::FULL,
+};
 
 trait TaskWarriorBool {
     fn get_bool(&self) -> Option<bool>;
@@ -45,7 +48,11 @@ pub struct Config {
     pub rule_precedence_color: Vec<String>,
     pub uda_priority_values: Vec<String>,
     pub uda_tick_rate: u64,
+    pub uda_auto_insert_double_quotes_on_add: bool,
+    pub uda_auto_insert_double_quotes_on_annotate: bool,
+    pub uda_auto_insert_double_quotes_on_log: bool,
     pub uda_prefill_task_metadata: bool,
+    pub uda_reset_filter_on_esc: bool,
     pub uda_task_detail_prefetch: usize,
     pub uda_task_report_show_info: bool,
     pub uda_task_report_looping: bool,
@@ -53,13 +60,16 @@ pub struct Config {
     pub uda_selection_indicator: String,
     pub uda_mark_indicator: String,
     pub uda_unmark_indicator: String,
+    pub uda_scrollbar_indicator: String,
+    pub uda_style_report_scrollbar: Style,
     pub uda_selection_bold: bool,
     pub uda_selection_italic: bool,
     pub uda_selection_dim: bool,
     pub uda_selection_blink: bool,
+    pub uda_selection_reverse: bool,
     pub uda_calendar_months_per_row: usize,
     pub uda_style_context_active: Style,
-    pub uda_report_style_selection: Style,
+    pub uda_style_report_selection: Style,
     pub uda_style_calendar_title: Style,
     pub uda_style_calendar_today: Style,
     pub uda_style_report_completion_pane: Style,
@@ -87,7 +97,11 @@ impl Config {
         let rule_precedence_color = Self::get_rule_precedence_color(data);
         let uda_priority_values = Self::get_uda_priority_values(data);
         let uda_tick_rate = Self::get_uda_tick_rate(data);
+        let uda_auto_insert_double_quotes_on_add = Self::get_uda_auto_insert_double_quotes_on_add(data);
+        let uda_auto_insert_double_quotes_on_annotate = Self::get_uda_auto_insert_double_quotes_on_annotate(data);
+        let uda_auto_insert_double_quotes_on_log = Self::get_uda_auto_insert_double_quotes_on_log(data);
         let uda_prefill_task_metadata = Self::get_uda_prefill_task_metadata(data);
+        let uda_reset_filter_on_esc = Self::get_uda_reset_filter_on_esc(data);
         let uda_task_detail_prefetch = Self::get_uda_task_detail_prefetch(data);
         let uda_task_report_show_info = Self::get_uda_task_report_show_info(data);
         let uda_task_report_looping = Self::get_uda_task_report_looping(data);
@@ -95,12 +109,15 @@ impl Config {
         let uda_selection_indicator = Self::get_uda_selection_indicator(data);
         let uda_mark_indicator = Self::get_uda_mark_indicator(data);
         let uda_unmark_indicator = Self::get_uda_unmark_indicator(data);
+        let uda_scrollbar_indicator = Self::get_uda_scrollbar_indicator(data);
         let uda_selection_bold = Self::get_uda_selection_bold(data);
         let uda_selection_italic = Self::get_uda_selection_italic(data);
         let uda_selection_dim = Self::get_uda_selection_dim(data);
         let uda_selection_blink = Self::get_uda_selection_blink(data);
+        let uda_selection_reverse = Self::get_uda_selection_reverse(data);
         let uda_calendar_months_per_row = Self::get_uda_months_per_row(data);
-        let uda_report_style_selection = Self::get_uda_style("report.selection", data);
+        let uda_style_report_selection = Self::get_uda_style("report.selection", data);
+        let uda_style_report_scrollbar = Self::get_uda_style("report.scrollbar", data);
         let uda_style_calendar_title = Self::get_uda_style("calendar.title", data);
         let uda_style_calendar_today = Self::get_uda_style("calendar.today", data);
         let uda_style_context_active = Self::get_uda_style("context.active", data);
@@ -108,7 +125,9 @@ impl Config {
         let uda_shortcuts = Self::get_uda_shortcuts(data);
         let uda_background_process = Self::get_uda_background_process(data);
         let uda_background_process_period = Self::get_uda_background_process_period(data);
-        let uda_report_style_selection = uda_report_style_selection.unwrap_or_default();
+        let uda_style_report_selection = uda_style_report_selection.unwrap_or_default();
+        let uda_style_report_scrollbar =
+            uda_style_report_scrollbar.unwrap_or_else(|| Style::default().fg(Color::Black));
         let uda_style_calendar_title = uda_style_calendar_title.unwrap_or_default();
         let uda_style_calendar_today =
             uda_style_calendar_today.unwrap_or_else(|| Style::default().add_modifier(Modifier::BOLD));
@@ -130,7 +149,11 @@ impl Config {
             rule_precedence_color,
             uda_priority_values,
             uda_tick_rate,
+            uda_auto_insert_double_quotes_on_add,
+            uda_auto_insert_double_quotes_on_annotate,
+            uda_auto_insert_double_quotes_on_log,
             uda_prefill_task_metadata,
+            uda_reset_filter_on_esc,
             uda_task_detail_prefetch,
             uda_task_report_show_info,
             uda_task_report_looping,
@@ -138,16 +161,19 @@ impl Config {
             uda_selection_indicator,
             uda_mark_indicator,
             uda_unmark_indicator,
+            uda_scrollbar_indicator,
             uda_selection_bold,
             uda_selection_italic,
             uda_selection_dim,
             uda_selection_blink,
+            uda_selection_reverse,
             uda_calendar_months_per_row,
-            uda_report_style_selection,
+            uda_style_report_selection,
             uda_style_context_active,
             uda_style_calendar_title,
             uda_style_calendar_today,
             uda_style_report_completion_pane,
+            uda_style_report_scrollbar,
             uda_shortcuts,
             uda_background_process,
             uda_background_process_period,
@@ -421,6 +447,30 @@ impl Config {
             .unwrap()
     }
 
+    fn get_uda_auto_insert_double_quotes_on_add(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.auto-insert-double-quotes-on-add", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(true)
+    }
+
+    fn get_uda_auto_insert_double_quotes_on_annotate(data: &str) -> bool {
+        Self::get_config(
+            "uda.taskwarrior-tui.task-report.auto-insert-double-quotes-on-annotate",
+            data,
+        )
+        .unwrap_or_default()
+        .get_bool()
+        .unwrap_or(true)
+    }
+
+    fn get_uda_auto_insert_double_quotes_on_log(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.auto-insert-double-quotes-on-log", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(true)
+    }
+
     fn get_uda_prefill_task_metadata(data: &str) -> bool {
         Self::get_config("uda.taskwarrior-tui.task-report.pre-fill-task-meta-data", data)
             .unwrap_or_default()
@@ -428,6 +478,13 @@ impl Config {
             .unwrap_or(false)
     }
 
+    fn get_uda_reset_filter_on_esc(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.reset-filter-on-esc", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(true)
+    }
+
     fn get_uda_tick_rate(data: &str) -> u64 {
         Self::get_config("uda.taskwarrior-tui.tick-rate", data)
             .unwrap_or_default()
@@ -501,6 +558,19 @@ impl Config {
         }
     }
 
+    fn get_uda_scrollbar_indicator(data: &str) -> String {
+        let indicator = Self::get_config("uda.taskwarrior-tui.scrollbar.indicator", data);
+        match indicator {
+            None => FULL.to_string(),
+            Some(indicator) => format!(
+                "{}",
+                indicator
+                    .chars()
+                    .next()
+                    .unwrap_or_else(|| FULL.to_string().chars().next().unwrap())
+            ),
+        }
+    }
     fn get_uda_mark_highlight_indicator(data: &str) -> String {
         let indicator = Self::get_config("uda.taskwarrior-tui.mark-selection.indicator", data);
         match indicator {
@@ -545,6 +615,13 @@ impl Config {
             .unwrap_or(false)
     }
 
+    fn get_uda_selection_reverse(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.selection.reverse", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(false)
+    }
+
     fn get_uda_months_per_row(data: &str) -> usize {
         Self::get_config("uda.taskwarrior-tui.calendar.months-per-row", data)
             .unwrap_or_default()
